==> xlog-0.9.6.tar.gz: xlog-0.9.6/src/hamlib-utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#if WANT_HAMLIB
void stop_hamlib (void);
gboolean start_hamlib (gchar *radio, gchar *device, gint debugmode, gint timervalue);
GList *riglist_get_list (void);
gint get_rigid (gchar * rig);
gchar *rigmode (gint mode);
void get_powerlevel(void);
void get_mode(void);
void get_frequency(void);
void get_ptt(void);
void get_smeter(void);
void get_riginfo (void);
gint poll_riginfo (void);
void sethamlibwidgets (gint status, gboolean initsmeter);
GString *convert_frequency (void);
gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget, GdkEventConfigure * event, gpointer user_data);
gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget, GdkEventExpose * event, gpointer user_data);
void on_mainwindow_show (GtkWidget * widget, gpointer user_data);
#endif

==> xlog_1.3.tar.gz: xlog-1.3/src/hamlib-utils.h <==
/*
 * xlog - GTK+ logging program for amateur radio operators
 * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#if WANT_HAMLIB
void stop_hamlib (void);
gboolean start_hamlib (gint rigid, gchar *device, gint debugmode, gint timervalue);
GList *riglist_get_list (void);
GList *rig_get_list (void);
gint get_rigid (gchar * rig);
gchar *rigmode (gint mode);
void get_powerlevel(void);
void get_mode(void);
void get_frequency(void);
void get_ptt(void);
void get_smeter(void);
void get_riginfo (void);
gint poll_riginfo (void);
void sethamlibwidgets (gint status, gboolean initsmeter);
GString *convert_frequency (void);
gboolean on_smeterdrawingarea_configure_event (GtkWidget * widget, GdkEventConfigure * event, gpointer user_data);
gboolean on_smeterdrawingarea_expose_event (GtkWidget * widget, GdkEventExpose * event, gpointer user_data);
void on_mainwindow_show (GtkWidget * widget, gpointer user_data);
#endif
